@@ -1,7 +1,7 @@
 from . import __version__
 from .ui import *
+from . import config
 
-import lank.node
 import lank.peer
 
 
@@ -65,6 +65,7 @@ class Labels(Component):
         super().__init__(parent, 0, 0)
 
         self.labels = [ ]
+        self.interests = config.load_interests()
         #self.refresh_labels(['foo', 'bar'])
 
     def refresh_labels(self, labels=None):
@@ -81,10 +82,18 @@ class Labels(Component):
             y = 30
             for label in labels:
                 def toggle(label):
-                    def toggle(toggled):
+                    def toggler(toggled):
+                        if toggled:
+                            if label not in self.interests:
+                                self.interests.append(label)
+                        else:
+                            if label in self.interests:
+                                del self.interests[self.interests.index(label)]
+                        config.save_interests(self.interests)
                         if self.win.app.node:
                             self.win.app.node.notify(label, toggled)
-                    return toggle
+
+                    return toggler
 
                 btn = ToggleButton(self, 3, y,
                     image('btn_bell.png'),
@@ -92,7 +101,8 @@ class Labels(Component):
                     image('btn_bell-hover.png'),
                     image('btn_bell-push.png'),
                     image('btn_bell-hover.png'),
-                    image('btn_bell-push.png'))
+                    image('btn_bell-push.png'),
+                    label in self.interests)
                 btn.on_toggle = toggle(label)
 
                 self.labels.append((btn, Label(self, 33, y+7, label)))
@@ -100,25 +110,17 @@ class Labels(Component):
 
 
 class Config(Component):
-    NODE_HOST = 'localhost'
-    NODE_PORT = lank.node.DEFAULT_PORT
     PEER_PORT = lank.peer.DEFAULT_PORT
 
     def __init__(self, parent):
         super().__init__(parent, 0, 0)
 
-        y = 180
-        #Label(self, 5, y, 'Node Host:')
-        #self.node_host = TextEntry(self, 100, y, 150, self.NODE_HOST)
-        y -= 40
-        #Label(self, 5, y, 'Node Port:')
-        #self.node_port = TextEntry(self, 100, y, 75, str(self.NODE_PORT))
-        y -= 40
+        y = 100
         Label(self, 5, y, 'Local Port:')
         self.peer_port = TextEntry(self, 100, y, 75, str(self.PEER_PORT))
         y -= 40
         Label(self, 5, y, 'Label:')
-        self.label = TextEntry(self, 100, y, 150)
+        self.label = TextEntry(self, 100, y, 150, config.load_connect_label())
         y -= 40
         Label(self, 5, y, 'Password:')
         self.pwd = TextEntry(self, 100, y, 150, mask='*')
